@@ -1,5 +1,5 @@
 import pg
-from dbconf import dbs
+from dbs import dbs
 
 class postgres(object):
 
